TypeHierarchy class

represents the type hierarchy of the public API of a package

Constructors

TypeHierarchy.empty()
creates an empty type hierarchy
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
registeredTypes List<TypeIdentifier>
returns all registered types in this type hierarchy
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

baseTypesOf(TypeIdentifier typeIdentifier) Set<TypeIdentifier>?
returns the base types of the given typeIdentifier if the base types are not retrievable then null is returned
clone() TypeHierarchy
clones this type hierarchy
containsType(TypeIdentifier typeIdentifier) bool
checks if this type hierarchy contains the given typeIdentifier
isCompatibleReplacement({required TypeIdentifier oldTypeIdentifier, required TypeIdentifier newTypeIdentifier, required bool isTypePassedIn}) bool
checks if newTypeIdentifier is a compatible replacement for oldTypeIdentifier
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerType(TypeIdentifier typeIdentifier, Set<TypeIdentifier> baseTypeIdentifiers) → void
registers the given typeIdentifier with the given baseTypeIdentifiers
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited